:
# daily.sh -- daily update from remotely spooled files

RemoteHost="owl"
RemoteBase="/usr/spool/uucppublic"
RemoteSub="news"
RemoteDir="$RemoteBase/$RemoteSub"
SpoolDir="/usr/spool/news/in.$RemoteHost"
InComingDir="/usr/spool/news/in.coming"
KeepName="keep"
RemoteKeep="$RemoteDir/$KeepName"

MailTarget=william

safe_df(){
	df -v `pwd` &
	sleep 3
}

DF="safe_df"

case `id` in
*news*) ;;
*)	echo "$0: Your id is not news"
	id | mail -s "$0 not run as news" $MailTarget
	exit
	;;
esac

if [ -f "dailysh.pid" ]
then
	echo "$0: Aborting, daily.sh already running"
	ls -l dailysh.pid
	cat dailysh.pid
	ls -l dailysh.pid | mail -s "$0 already running" $MailTarget
	exit
fi

echo $$ > dailysh.pid

got_uucp_files=no
got_spooled_files=no
got_incoming_files=no
spooled_file_list=
incoming_file_list=
errors=

set -x

$DF

files=`rcmd $RemoteHost ls $RemoteDir`

if [ "$files" = "$KeepName" ]
then
	files=
	echo "No news files"
elif [ -z "$files" ]
then
	echo "$0: Warning: keep missing, no files"

	base_files=`rcmd $RemoteHost ls $RemoteBase | grep \^$RemoteSub\$`
	if [ -z "$base_files" ]
	then
		echo "$0: Warning: $RemoteDir missing"
		errors="$errors $RemoteDir missing"
		if rcmd $RemoteHost mkdir -m 777 -p $RemoteDir
		then
			x=x
		else
			echo "$0: Error: rcmd mkdir $RemoteDir failed"
			errors="$errors rcmd-mkdir-failed"
		fi	
		base_files=`rcmd $RemoteHost ls $RemoteBase | grep \^$RemoteSub\$`
		if [ -z "$base_files" ]
		then
			echo "$0: Warning: create for $RemoteDir failed"
			errors="$errors $RemoteDir not-created"
		fi
	fi
fi

if rcmd $RemoteHost touch $RemoteKeep
then
	x=x
else
	echo "$0: Warning: touch $RemoteKeep failed"
	errors="$errors touch $RemoteKeep failed"
fi

# echo "err $errors"
# exit

echo "Checking news integrity"
if /usr/lib/newsbin/maint/newswatch
then
	x=x
else
	errors="$errors newswatch1-top"
fi

if tty -s
then
	echo "Interactive session, not expiring old news"
elif [ -z "$files" ]
then
	echo "No files, not expiring old news"
else
	echo "Expiring old news"
	if /usr/lib/newsbin/expire/doexpire
	then
		x=x
	else
		errors="$errors doexpire"
	fi

	echo "Updating article limits"
	if /usr/lib/newsbin/expire/upact
	then
		x=x
	else
		errors="$errors upact"
	fi

	echo "Rechecking news integrity"
	if /usr/lib/newsbin/maint/newswatch
	then
		x=x
	else
		errors="$errors newswatch2-upact"
	fi

	echo "Disk space:"
	$DF
fi

for file in $files
do
	case "$file" in
	rnews*-*) ;;
	*)	if [ "$file" != "$KeepName" ]
		then
			echo "$0: Skipping file $file in $RemoteDir"
			errors="$errors skipping-$RemoteDir/$file"
		fi
		continue
		;;
	esac

	echo "Copying $file ..."

	if rcp "${RemoteHost}:$RemoteDir/$file" "$SpoolDir/$file"
	then
		if [ -f "$SpoolDir/$file" ]
		then
			echo "Copy OK"
			ls -l "$SpoolDir/$file"
			got_uucp_files=yes
			if rcmd $RemoteHost rm -f "$RemoteDir/$file"
			then
				echo "Removed $RemoteHost rm $RemoteDir/$file"
			else
				echo "rcmd $RemoteHost rm $RemoteDir failed"
				errors="$errors rcmd rm"
			fi
		else
			echo "rcp returned OK but copy is bad"
			errors="$errors rcp-not-created"
		fi
	else
		echo "rcmd failed"
		errors="$errors rcp"
	fi
done

for file in $SpoolDir/*
do
	if [ -f "$file" ]
	then
		echo "Loading $file with rnews ..."

		echo "Copying the batch with rnews"
		if /usr/lib/newsbin/input/rnews < "$file"
		then
			rm -f "$file"
			got_spooled_files=yes
			spooled_file_list="$spooled_file_list $file"
		else
			echo "Error copying $file"
			errors="$errors cp-$file"
		fi
	fi
done

for file in $InComingDir/*
do
	if [ -f "$file" ]
	then
		got_incoming_files=yes
		incoming_file_list="$incoming_file_list $file"
	fi
done

if [ "$got_spooled_files" = no -a "$got_incoming_files" = no ]
then
	echo "No new files, skipping newsrun"
else
	echo "Updating the batch with newsrun"
	if /usr/lib/newsbin/input/newsrun
	then
		x=x
	else
		errors="$errors newsrun"
	fi

	echo "Rechecking news integrity"
	if /usr/lib/newsbin/maint/newswatch
	then
		x=x
	else
		errors="$errors newswatch3-newsrun"
	fi

	if tty -s
	then
		echo "Interactive session, not rolling logs"
	else
		echo "Rolling daily news logs"
		if /usr/lib/newsbin/maint/newsdaily
		then
			x=x
		else
			errors="$errors newsdaily"
		fi

		echo "Rechecking news integrity"
		if /usr/lib/newsbin/maint/newswatch
		then
			x=x
		else
			errors="$errors newswatch4-newsdaily"
		fi
	fi


	echo "Disk space:"
	$DF
fi

mesg="Finished daily at `date`"

echo "$mesg"

echo "$mesg" > mesg.txt
echo "got_uucp_files: $got_uucp_files" >> mesg.txt
echo "got_spooled_files: $got_spooled_files" >> mesg.txt
echo "spooled_file_list: $spooled_file_list" >> mesg.txt
echo "got_incoming_files: $got_incoming_files" >> mesg.txt
echo "incoming_file_list: $incoming_file_list" >> mesg.txt
echo "errors: $errors" >> mesg.txt

if [ "$got_uucp_files" = no -a \
	"$got_spooled_files" = no -a \
	"$got_incoming_files" = no -a \
	-z "$errors" ]
then
	echo "Not mailing, no new files"
else
	mail -s "$mesg" $MailTarget < mesg.txt
fi

rm -f dailysh.pid
